<?php
/**
 * Register Horizontal Type 5.
 *
 * @package Verta
 */

/**
 * Register New Layout
 *
 * @param array $layouts List of layouts.
 */
function csco_canvas_register_layout_horizontal_type_5( $layouts = array() ) {

	$layout = 'horizontal-type-5';

	// Add new layout.
	$layouts[ $layout ] = array(
		'location'    => array(),
		'name'        => esc_html__( 'Horizontal 5', 'verta' ),
		'template'    => get_template_directory() . '/template-parts/blocks/posts-area.php',
		'icon'        => '<svg height="44" viewBox="0 0 52 44" width="52" xmlns="http://www.w3.org/2000/svg"><g fill="none" fill-rule="evenodd" stroke="#2d2d2d"><rect height="42" rx="3" stroke-width="1.5" width="50" x="1" y="1"/><rect height="20" rx="1" stroke-width="1.5" width="20" x="6" y="12"/><g stroke-linecap="round" stroke-linejoin="round"><path d="m30.5 13h7"/><path d="m30.5 16h16"/><path d="m30.5 19h5"/></g></g></svg>',
		'sections'    => array(
			'general'    => array(
				'title'    => esc_html__( 'Block Settings', 'verta' ),
				'priority' => 5,
				'open'     => true,
			),
			'post-meta'  => array(
				'title'    => esc_html__( 'Meta Settings', 'verta' ),
				'priority' => 10,
			),
			'typography' => array(
				'title'    => esc_html__( 'Typography Settings', 'verta' ),
				'priority' => 10,
			),
		),
		'hide_fields' => csco_get_gutenberg_posts_hide_fields(),
		'fields'      => array_merge(
			csco_get_gutenberg_pagination_fields(),

			array(
				array(
					'key'            => 'columns',
					'label'          => esc_html__( 'Number of Columns', 'verta' ),
					'section'        => 'general',
					'type'           => 'number',
					'min'            => 1,
					'max'            => 6,
					'default'        => 1,
					'default_tablet' => 1,
					'default_mobile' => 1,
					'responsive'     => true,
					'output'         => array(
						array(
							'element'  => '$ .cs-posts-area__main',
							'property' => '--cs-posts-area-grid-columns',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'            => 'gap_posts',
					'label'          => esc_html__( 'Gap between Posts', 'verta' ),
					'type'           => 'dimension',
					'section'        => 'general',
					'responsive'     => true,
					'default'        => '40px',
					'default_tablet' => '40px',
					'default_mobile' => '40px',
					'output'         => array(
						array(
							'element'  => '$ .cs-posts-area__main',
							'property' => '--cs-posts-area-grid-gap',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'bordersBetweenPosts',
					'label'   => esc_html__( 'Display borders between posts', 'verta' ),
					'section' => 'general',
					'type'    => 'toggle',
					'default' => false,
				),
				array(
					'key'             => 'meta_category_type',
					'label'           => esc_html__( 'Category type', 'verta' ),
					'section'         => 'post-meta',
					'type'            => 'select',
					'default'         => '',
					'choices'         => array(
						'one'   => esc_html__( 'Type 1', 'verta' ),
						'two'   => esc_html__( 'Type 2', 'verta' ),
						'three' => esc_html__( 'Type 3', 'verta' ),
					),
					'active_callback' => array(
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				// Typography.
				array(
					'key'        => 'typographyHeading',
					'label'      => esc_html__( 'Heading Font Size', 'verta' ),
					'section'    => 'typography',
					'type'       => 'dimension',
					'default'    => '1.125rem',
					'responsive' => true,
					'output'     => array(
						array(
							'element'  => '$ .cs-entry__title',
							'property' => 'font-size',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'typographyHeadingTag',
					'label'   => esc_html__( 'Heading Tag', 'verta' ),
					'section' => 'typography',
					'type'    => 'select',
					'default' => 'h2',
					'choices' => array(
						'h1'  => esc_html__( 'H1', 'verta' ),
						'h2'  => esc_html__( 'H2', 'verta' ),
						'h3'  => esc_html__( 'H3', 'verta' ),
						'h4'  => esc_html__( 'H4', 'verta' ),
						'h5'  => esc_html__( 'H5', 'verta' ),
						'h6'  => esc_html__( 'H6', 'verta' ),
						'p'   => esc_html__( 'P', 'verta' ),
						'div' => esc_html__( 'DIV', 'verta' ),
					),
				),
				array(
					'key'             => 'typographyExcerpt',
					'label'           => esc_html__( 'Excerpt Font Size', 'verta' ),
					'section'         => 'typography',
					'type'            => 'dimension',
					'default'         => '1rem',
					'responsive'      => true,
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__excerpt',
							'property' => 'font-size',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#showExcerpt',
							'operator' => '===',
							'value'    => true,
						),
					),
				),
				// Color Settings.
				array(
					'key'     => 'colorBasicHeading',
					'label'   => esc_html__( 'Heading', 'verta' ),
					'section' => 'color',
					'type'    => 'color',
					'output'  => array(
						array(
							'element'  => '$ .cs-entry__title a',
							'property' => 'color',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'colorBasicHeadingHover',
					'label'   => esc_html__( 'Heading Hover', 'verta' ),
					'section' => 'color',
					'type'    => 'color',
					'output'  => array(
						array(
							'element'  => '$ .cs-entry__title a:hover, $ .cs-entry__title a:focus',
							'property' => 'color',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'             => 'colorBasicExcerpt',
					'label'           => esc_html__( 'Excerpt', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__excerpt',
							'property' => 'color',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#showExcerpt',
							'operator' => '===',
							'value'    => true,
						),
					),
				),
				array(
					'key'     => 'colorBasicMeta',
					'label'   => esc_html__( 'Post Meta', 'verta' ),
					'section' => 'color',
					'type'    => 'color',
					'output'  => array(
						array(
							'element'  => '$ .cs-entry__post-meta',
							'property' => 'color',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'colorBasicMetaLinks',
					'label'   => esc_html__( 'Post Meta Links', 'verta' ),
					'section' => 'color',
					'type'    => 'color',
					'output'  => array(
						array(
							'element'  => '$ .cs-entry__post-meta div:not(.cs-meta-category) a',
							'property' => 'color',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'colorBasicMetaLinksHover',
					'label'   => esc_html__( 'Post Meta Links Hover', 'verta' ),
					'section' => 'color',
					'type'    => 'color',
					'output'  => array(
						array(
							'element'  => '$ .cs-entry__post-meta div:not(.cs-meta-category) a:hover, $ .cs-entry__post-meta div:not(.cs-meta-category) a:focus',
							'property' => 'color',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'             => 'colorBasicCategory',
					'label'           => esc_html__( 'Category Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__post-meta .cs-meta-category, $ .cs-entry__post-meta .cs-meta-category a',
							'property' => '--cs-color-category',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#meta_category_type',
							'operator' => '!=',
							'value'    => 'two',
						),
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategoryHover',
					'label'           => esc_html__( 'Category Hover Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__post-meta .cs-meta-category a:hover',
							'property' => '--cs-color-category-hover',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#meta_category_type',
							'operator' => '!=',
							'value'    => 'two',
						),
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategories',
					'label'           => esc_html__( 'Styled Category Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-meta-category, $ .cs-meta-category a',
							'property' => '--cs-color-styled-category-contrast',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#meta_category_type',
							'operator' => '==',
							'value'    => 'two',
						),
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategoriesHover',
					'label'           => esc_html__( 'Styled Category Hover Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-meta-category:hover, $ .cs-meta-category a:hover',
							'property' => '--cs-color-styled-category-hover-contrast',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#meta_category_type',
							'operator' => '==',
							'value'    => 'two',
						),
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategoriesBG',
					'label'           => esc_html__( 'Styled Category Background', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-meta-category a',
							'property' => '--cs-color-styled-category',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#meta_category_type',
							'operator' => '==',
							'value'    => 'two',
						),
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategoriesBGHover',
					'label'           => esc_html__( 'Styled Category Background Hover', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-meta-category a:hover',
							'property' => '--cs-color-styled-category-hover',
							'suffix'   => '!important',
						),
						array(
							'element'  => '$ .cs-meta-category a:hover',
							'property' => '--cs-color-styled-category',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#meta_category_type',
							'operator' => '==',
							'value'    => 'two',
						),
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategoryUnderline',
					'label'           => esc_html__( 'Category Underline Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-meta-category',
							'property' => '--cs-color-category-underline',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#meta_category_type',
							'operator' => '==',
							'value'    => 'three',
						),
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'     => 'colorBadge',
					'label'   => esc_html__( 'Badge Color', 'verta' ),
					'section' => 'color',
					'type'    => 'color',
					'output'  => array(
						array(
							'element'  => '$ .cs-entry__title a:before',
							'property' => '--cs-color-accent',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'             => 'morebutton_background',
					'label'           => esc_html__( 'More Button Background Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__read-more a',
							'property' => '--cs-color-button',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#moreButton',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'morebutton_background_hover',
					'label'           => esc_html__( 'More Button Background Hover Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__read-more a:hover',
							'property' => '--cs-color-button-hover',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#moreButton',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
			),
			// Primary Meta.
			csco_get_gutenberg_meta_fields(
				array(
					'section_name' => 'post-meta',
					'default'      => array(
						'category'     => false,
						'author'       => false,
						'date'         => false,
						'comments'     => false,
						'views'        => true,
						'reading_time' => false,
						'shares'       => true,
						'photos'       => false,
						'duration'     => false,
					),
				)
			),
			csco_get_gutenberg_excerpt_fields(
				array(
					'section_name' => 'post-meta',
					'default'      => false,
				)
			),
			csco_get_gutenberg_more_button_fields(
				array(
					'section_name' => 'post-meta',
					'default'      => false,
				)
			)
		),
	);

	return $layouts;
}
add_filter( 'canvas_block_layouts_canvas/posts', 'csco_canvas_register_layout_horizontal_type_5' );
