<?php
/**
 * Editor Settings.
 *
 * @package Verta
 */

/**
 * Enqueue editor scripts
 */
function csco_block_editor_scripts() {
	wp_enqueue_script(
		'csco-editor-scripts',
		get_template_directory_uri() . '/assets/jsx/editor-scripts.js',
		array(
			'wp-editor',
			'wp-element',
			'wp-compose',
			'wp-data',
			'wp-plugins',
		),
		csco_get_theme_data( 'Version' ),
		true
	);
}
add_action( 'enqueue_block_editor_assets', 'csco_block_editor_scripts' );

/**
 * Adds classes to <div class="editor-styles-wrapper"> tag
 */
function csco_block_editor_wrapper() {
	$post_id = get_the_ID();

	if ( ! $post_id ) {
		return;
	}

	// Set post type.
	$post_type = sprintf( 'post-type-%s', get_post_type( $post_id ) );

	// Set page layout.
	$default_layout = csco_get_page_sidebar( $post_id, 'default' );
	$page_layout    = csco_get_page_sidebar( $post_id, false );

	if ( 'disabled' === $default_layout ) {
		$default_layout = 'cs-sidebar-disabled';
	} else {
		$default_layout = 'cs-sidebar-enabled';
	}

	if ( 'disabled' === $page_layout ) {
		$page_layout = 'cs-sidebar-disabled';
	} else {
		$page_layout = 'cs-sidebar-enabled';
	}

	// Post Sidebar.
	if ( 'post' === get_post_type( $post_id ) && csco_powerkit_module_enabled( 'share_buttons' ) && powerkit_share_buttons_exists( 'metabar-post' ) ) {
		$post_sidebar = 'cs-metabar-enabled';
	} else {
		$post_sidebar = 'cs-metabar-disabled';
	}

	// Section Heading.
	$section_heading = 'section-heading-default-' . get_theme_mod( 'section_heading', 'style-1' );

	// Form Style Type.
	$form_style = 'cs-form-styled-' . get_theme_mod( 'form_style_content', 'three' );

	wp_enqueue_script(
		'csco-editor-wrapper',
		get_template_directory_uri() . '/assets/jsx/gutenberg-wrapper.js',
		array(
			'wp-editor',
			'wp-element',
			'wp-compose',
			'wp-data',
			'wp-plugins',
		),
		csco_get_theme_data( 'Version' ),
		true
	);

	wp_localize_script(
		'csco-editor-wrapper',
		'cscoGWrapper',
		array(
			'post_type'       => $post_type,
			'default_layout'  => $default_layout,
			'page_layout'     => $page_layout,
			'post_sidebar'    => $post_sidebar,
			'section_heading' => $section_heading,
			'form_style'      => $form_style,
		)
	);
}
add_action( 'enqueue_block_editor_assets', 'csco_block_editor_wrapper' );

/**
 * Change editor color palette.
 */
function csco_change_editor_color_palette() {
	// Editor Color Palette.
	add_theme_support(
		'editor-color-palette',
		array(
			array(
				'name'  => esc_html__( 'Blue', 'verta' ),
				'slug'  => 'blue',
				'color' => '#59BACC',
			),
			array(
				'name'  => esc_html__( 'Green', 'verta' ),
				'slug'  => 'green',
				'color' => '#03a988',
			),
			array(
				'name'  => esc_html__( 'Orange', 'verta' ),
				'slug'  => 'orange',
				'color' => '#FFBC49',
			),
			array(
				'name'  => esc_html__( 'Red', 'verta' ),
				'slug'  => 'red',
				'color' => '#fb0d48',
			),
			array(
				'name'  => esc_html__( 'Pale Pink', 'verta' ),
				'slug'  => 'pale-pink',
				'color' => '#f78da7',
			),
			array(
				'name'  => esc_html__( 'White', 'verta' ),
				'slug'  => 'white',
				'color' => '#FFFFFF',
			),
			array(
				'name'  => esc_html__( 'Secondary Background', 'verta' ),
				'slug'  => 'secondary-bg',
				'color' => get_theme_mod( 'color_secondary_background', '#f8f3ee' ),
			),
			array(
				'name'  => esc_html__( 'Accent Background', 'verta' ),
				'slug'  => 'accent-bg',
				'color' => get_theme_mod( 'color_accent_background', '#ddefe9' ),
			),
			array(
				'name'  => esc_html__( 'Additional', 'verta' ),
				'slug'  => 'additional',
				'color' => get_theme_mod( 'color_additional', '#484848' ),
			),
			array(
				'name'  => esc_html__( 'Secondary', 'verta' ),
				'slug'  => 'secondary',
				'color' => get_theme_mod( 'color_secondary', '#818181' ),
			),
			array(
				'name'  => esc_html__( 'Black', 'verta' ),
				'slug'  => 'black',
				'color' => '#000000',
			),
			array(
				'name'  => esc_html__( 'Gray 50', 'verta' ),
				'slug'  => 'gray-50',
				'color' => '#f8f9fa',
			),
			array(
				'name'  => esc_html__( 'Gray 100', 'verta' ),
				'slug'  => 'gray-100',
				'color' => '#f8f9fb',
			),
			array(
				'name'  => esc_html__( 'Gray 200', 'verta' ),
				'slug'  => 'gray-200',
				'color' => '#e9ecef',
			),
		)
	);
}
add_action( 'after_setup_theme', 'csco_change_editor_color_palette' );
