<?php
/**
 * Powerkit Filters
 *
 * @package Verta
 */

/**
 * New Share Buttons Locations
 *
 * @param array $locations List of Locations.
 */
function csco_powerkit_new_share_buttons_locations( $locations = array() ) {

	$locations['post-header'] = array(
		'shares'         => array( 'facebook', 'twitter', 'pinterest' ),
		'name'           => esc_html__( 'Post Header', 'verta' ),
		'location'       => 'post-header',
		'mode'           => 'cached',
		'before'         => '',
		'after'          => '',
		'display'        => true,
		'meta'           => array(
			'icons'  => true,
			'titles' => false,
			'labels' => false,
		),
		// Display only the specified layouts and color schemes.
		'fields'         => array(
			'layouts'         => array( 'simple' ),
			'schemes'         => array( 'simple-light', 'bold-light' ),
			'count_locations' => array( 'inside' ),
		),
		'display_total'  => true,
		'layout'         => 'simple',
		'scheme'         => 'simple-light',
		'count_location' => 'inside',
	);

	$locations['after-post'] = array(
		'shares'         => array( 'facebook', 'twitter', 'pinterest' ),
		'name'           => esc_html__( 'After Post Content', 'verta' ),
		'location'       => 'after-post',
		'mode'           => 'mixed',
		'before'         => '',
		'after'          => '',
		'display'        => true,
		'fields'         => array(
			'display_count'   => true,
			'layouts'         => array( 'simple' ),
			'schemes'         => array( 'simple-light', 'bold-light' ),
			'count_locations' => array( 'inside' ),
		),
		'display_total'  => true,
		'scheme'         => 'simple-light',
		'count_location' => 'inside',
	);

	$locations['metabar-post'] = array(
		'shares'         => array( 'facebook', 'twitter', 'pinterest' ),
		'name'           => esc_html__( 'Entry Metabar', 'verta' ),
		'location'       => 'metabar-post',
		'mode'           => 'mixed',
		'before'         => '',
		'after'          => '',
		'display'        => true,
		'meta'           => array(
			'icons'  => true,
			'titles' => false,
			'labels' => false,
		),
		// Display only the specified layouts and color schemes.
		'fields'         => array(
			'display_total'   => true,
			'display_count'   => true,
			'layouts'         => array( 'simple' ),
			'schemes'         => array( 'simple-light', 'bold-light' ),
			'count_locations' => array( 'inside' ),
		),
		'layout'         => 'simple',
		'scheme'         => 'simple-light',
		'count_location' => 'inside',
	);

	$locations['post-meta'] = array(
		'shares'         => array( 'facebook', 'twitter', 'pinterest' ),
		'name'           => esc_html__( 'Post Meta', 'verta' ),
		'location'       => 'post-meta',
		'mode'           => 'cached',
		'before'         => '',
		'after'          => '',
		'display'        => true,
		'meta'           => array(
			'icons'  => true,
			'titles' => false,
			'labels' => false,
		),
		// Display only the specified layouts and color schemes.
		'fields'         => array(
			'layouts'         => array( 'simple' ),
			'schemes'         => array( 'simple-light', 'bold-light' ),
			'count_locations' => array( 'inside' ),
		),
		'display_total'  => true,
		'layout'         => 'simple',
		'scheme'         => 'simple-light',
		'count_location' => 'inside',
	);

	return $locations;
}
add_filter( 'powerkit_share_buttons_locations', 'csco_powerkit_new_share_buttons_locations' );

/**
 * Change Share Buttons Locations
 *
 * @param array $locations List of Locations.
 */
function csco_powerkit_change_share_buttons_locations( $locations = array() ) {

	unset( $locations['before-content'] );
	unset( $locations['after-content'] );

	$locations['highlight-text'] = array(
		'shares'        => array( 'facebook', 'twitter', 'pinterest', 'mail' ),
		'name'          => '⚡ Highlight Text',
		'location'      => 'highlight-text',
		'mode'          => 'none',
		'before'        => '',
		'after'         => '',
		'meta'          => array(
			'icons'  => true,
			'titles' => false,
			'labels' => false,
		),
		'fields'        => array(
			'display_total'   => false,
			'display_count'   => false,
			'title_locations' => array(),
			'count_locations' => array(),
			'label_locations' => array(),
			'layouts'         => array( 'simple' ),
			'schemes'         => array( 'simple-light', 'bold-light' ),
		),
		'display_total' => false,
		'layout'        => 'simple',
		'scheme'        => 'simple-light',
		'attrs'         => 'data-scheme="default"',
	);

	$locations['blockquote'] = array(
		'shares'        => array( 'facebook', 'twitter' ),
		'name'          => '⭐ Blockquote',
		'location'      => 'blockquote',
		'mode'          => 'none',
		'before'        => '',
		'after'         => '',
		'meta'          => array(
			'icons'  => true,
			'titles' => false,
			'labels' => true,
		),
		'fields'        => array(
			'display_total'   => false,
			'display_count'   => false,
			'title_locations' => array(),
			'count_locations' => array(),
			'label_locations' => array(),
			'layouts'         => array( 'simple' ),
			'schemes'         => array( 'simple-light', 'bold-light' ),
		),
		'display_total' => false,
		'layout'        => 'simple',
		'scheme'        => 'simple-light',
	);

	$locations['mobile-share'] = array(
		'shares'   => array( 'facebook', 'pinterest', 'twitter', 'mail' ),
		'name'     => '📱 Mobile Share',
		'location' => 'mobile-share',
		'mode'     => 'none',
		'before'   => '',
		'after'    => '',
		'meta'     => array(
			'icons'  => true,
			'titles' => false,
			'labels' => false,
		),
		'fields'   => array(
			'display_total'   => false,
			'display_count'   => true,
			'title_locations' => array(),
			'count_locations' => array(),
			'label_locations' => array(),
			'schemes'         => array( 'default', 'simple-dark-back', 'bold-bg', 'bold' ),
			'layouts'         => array( 'horizontal', 'left-side', 'right-side', 'popup' ),
		),
		'layout'   => 'horizontal',
	);

	return $locations;
}
add_filter( 'powerkit_share_buttons_locations', 'csco_powerkit_change_share_buttons_locations', 9999 );

/**
 * Register Floated Share Buttons Location
 */
function csco_powerkit_widget_author_image_size() {
	return 'csco-thumbnail-uncropped';
}
add_filter( 'powerkit_widget_author_image_size', 'csco_powerkit_widget_author_image_size' );

/**
 * Change Contributors widget post author description length.
 */
function csco_powerkit_widget_contributors_description_length() {
	return 80;
}
add_filter( 'powerkit_widget_contributors_description_length', 'csco_powerkit_widget_contributors_description_length' );

/**
 * Add new settings to Widget Posts
 *
 * @param array $settings The settings.
 */
function csco_powerkit_widget_posts_settings( $settings ) {

	$settings = array_merge(
		$settings,
		array(
			'image_size'         => 'csco-smaller',
			'image_radius'       => '',
			'post_meta'          => array( 'category', 'date', 'views' ),
			'post_meta_category' => true,
		)
	);

	return $settings;
}
add_filter( 'powerkit_widget_posts_settings', 'csco_powerkit_widget_posts_settings' );

/**
 * Add new field to Widget Posts
 *
 * @param object $context  The context.
 * @param array  $params   The params.
 * @param array  $instance Current settings.
 */
function csco_powerkit_widget_posts_form_after( $context, $params, $instance ) {
	$image_sizes = csco_get_list_available_image_sizes();
	?>

		<!-- Images Size -->
		<p>
			<label for="<?php echo esc_attr( $context->get_field_id( 'image_size' ) ); ?>"><?php esc_html_e( 'Images Size', 'verta' ); ?>:</label>
			<select name="<?php echo esc_attr( $context->get_field_name( 'image_size' ) ); ?>" id="<?php echo esc_attr( $context->get_field_id( 'image_size' ) ); ?>" class="widefat">
				<?php foreach ( $image_sizes as $key => $size ) { ?>
					<option value="<?php echo esc_attr( $key ); ?>" <?php selected( $params['image_size'], $key ); ?>><?php echo esc_html( $size ); ?></option>
				<?php } ?>
			</select>
		</p>

		<!-- Image Border Radius -->
		<p>
			<label for="<?php echo esc_attr( $context->get_field_id( 'image_radius' ) ); ?>"><?php esc_html_e( 'Image Border Radius', 'verta' ); ?>:</label>
			<input class="widefat" id="<?php echo esc_attr( $context->get_field_id( 'image_radius' ) ); ?>" class="checkbox" name="<?php echo esc_attr( $context->get_field_name( 'image_radius' ) ); ?>" type="text" value="<?php echo esc_attr( $params['image_radius'] ); ?>" />
		</p>
	<?php
}
add_action( 'powerkit_widget_posts_form_after', 'csco_powerkit_widget_posts_form_after', 10, 3 );

/**
 * Change Default Template for featured posts
 *
 * @param array $templates The templates.
 */
function csco_powerkit_featured_posts_default( $templates = array() ) {
	$templates['list']['func']     = 'csco_powerkit_featured_default_template';
	$templates['numbered']['func'] = 'csco_powerkit_featured_default_template';
	$templates['large']['func']    = 'csco_powerkit_featured_default_template';

	return $templates;
}
add_filter( 'powerkit_featured_posts_templates', 'csco_powerkit_featured_posts_default' );

/**
 * Featured Default Template Callback
 *
 * @param  array $posts    Array of posts.
 * @param  array $params   Array of params.
 * @param  array $instance Widget instance.
 */
function csco_powerkit_featured_default_template( $posts, $params, $instance ) {

	$style = sprintf( '--cs-thumbnail-border-radius: %s;', $params['image_radius'] ? $params['image_radius'] : '0' );
	?>
	<article <?php post_class(); ?> style="<?php echo esc_attr( $style ); ?>">
		<div class="pk-post-outer">
			<?php
				$thumbnail_size = ( 'large' === $params['template'] ) ? 'pk-thumbnail' : 'pk-small';

				$thumbnail_size = apply_filters( 'powerkit_widget_featured_posts_size', $thumbnail_size, $params, $instance );
			?>
			<?php if ( has_post_thumbnail() ) { ?>
				<div class="pk-post-inner pk-post-thumbnail">
					<a href="<?php the_permalink(); ?>" class="post-thumbnail">
						<?php the_post_thumbnail( $thumbnail_size ); ?>

						<?php if ( 'numbered' === $params['template'] ) : ?>
							<span class="pk-post-number pk-bg-primary">
								<?php echo esc_html( $posts->current_post + 1 ); ?>
							</span>
						<?php endif; ?>
					</a>
				</div>
			<?php } ?>

			<div class="pk-post-inner pk-post-data">
				<?php
					powerkit_get_post_meta( 'category', (bool) $params['post_meta_compact'], true, $params['post_meta'] );
				?>

				<?php
				$tag = ( 'large' === $params['template'] ) ? 'h5' : 'h6';

				$tag = apply_filters( 'powerkit_widget_featured_posts_title_tag', $tag, $params, $instance );
				?>

				<<?php echo esc_html( $tag ); ?> class="entry-title">
					<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
				</<?php echo esc_html( $tag ); ?>>

				<?php
					powerkit_get_post_meta( powerkit_allowed_post_meta( true, 'category' ), (bool) $params['post_meta_compact'], true, $params['post_meta'] );
				?>
			</div>
		</div>
	</article>
	<?php
}

/**
 * Change tiles featured categories
 *
 * @param string $locations List locations.
 */
function csco_powerkit_featured_categories_locations( $locations ) {
	$image_sizes = csco_get_list_available_image_sizes();

	$locations['tiles'] = array(
		'name'        => esc_html__( 'Tiles', 'verta' ),
		'icon'        => '<svg width="52" height="44" xmlns="http://www.w3.org/2000/svg"><g transform="translate(1 1)" stroke="#2D2D2D" fill="none" fill-rule="evenodd"><rect stroke-width="1.5" width="50" height="42" rx="3"/><g transform="translate(7 9)"><rect stroke-width="1.5" width="36" height="24" rx="1"/><path d="M11 10.5h14m-11 3h9" stroke-linecap="round" stroke-linejoin="round"/></g></g></svg>',
		'location'    => array(),
		'template'    => get_template_directory() . '/template-parts/blocks/categories-tiles.php',
		'sections'    => array(
			'general'    => array(
				'title'    => esc_html__( 'Block Settings', 'verta' ),
				'priority' => 5,
				'open'     => true,
			),
			'typography' => array(
				'title'    => esc_html__( 'Typography Settings', 'verta' ),
				'priority' => 10,
			),
			'thumbnail'  => array(
				'title'    => esc_html__( 'Thumbnail Settings', 'verta' ),
				'priority' => 40,
			),
			'color'      => array(
				'title'    => esc_html__( 'Color Settings', 'verta' ),
				'priority' => 50,
			),
		),
		'hide_fields' => array(
			'number',
			'bgOverlay',
			'bgOpacityOverlay',
		),
		'fields'      => array(
			array(
				'key'            => 'columns',
				'label'          => esc_html__( 'Number of Columns', 'verta' ),
				'section'        => 'general',
				'type'           => 'number',
				'min'            => 1,
				'max'            => 6,
				'default'        => 1,
				'default_tablet' => 1,
				'default_mobile' => 1,
				'responsive'     => true,
				'output'         => array(
					array(
						'element'  => '$ .cs-tiles-categories__wrap',
						'property' => '--cs-categories-grid-columns',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'            => 'gap_posts',
				'label'          => esc_html__( 'Gap between Categories', 'verta' ),
				'type'           => 'dimension',
				'section'        => 'general',
				'responsive'     => true,
				'default'        => '40px',
				'default_tablet' => '40px',
				'default_mobile' => '40px',
				'output'         => array(
					array(
						'element'  => '$ .cs-tiles-categories__wrap',
						'property' => '--cs-categories-grid-gap',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'     => 'descriptionLength',
				'label'   => esc_html__( 'Description length', 'verta' ),
				'section' => 'general',
				'type'    => 'number',
				'step'    => 1,
				'min'     => 0,
				'max'     => 1000,
				'default' => 100,
			),
			// Typography.
			array(
				'key'        => 'typographyHeading',
				'label'      => esc_html__( 'Heading Font Size', 'verta' ),
				'section'    => 'typography',
				'type'       => 'dimension',
				'default'    => '1.625rem',
				'responsive' => true,
				'output'     => array(
					array(
						'element'  => '$ .cs-tiles-categories__name',
						'property' => 'font-size',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'     => 'typographyHeadingTag',
				'label'   => esc_html__( 'Heading Tag', 'verta' ),
				'section' => 'typography',
				'type'    => 'select',
				'default' => 'div',
				'choices' => array(
					'h1'   => esc_html__( 'H1', 'verta' ),
					'h2'   => esc_html__( 'H2', 'verta' ),
					'h3'   => esc_html__( 'H3', 'verta' ),
					'h4'   => esc_html__( 'H4', 'verta' ),
					'h5'   => esc_html__( 'H5', 'verta' ),
					'h6'   => esc_html__( 'H6', 'verta' ),
					'p'    => esc_html__( 'P', 'verta' ),
					'div'  => esc_html__( 'DIV', 'verta' ),
					'span' => esc_html__( 'SPAN', 'verta' ),
				),
			),
			// Thumbnail.
			array(
				'key'     => 'featured_image',
				'label'   => esc_html__( 'Display Featured Image', 'verta' ),
				'section' => 'thumbnail',
				'type'    => 'toggle',
				'default' => true,
			),
			array(
				'key'             => 'orientation',
				'label'           => esc_html__( 'Image Orientation', 'verta' ),
				'section'         => 'thumbnail',
				'type'            => 'select',
				'default'         => 'original',
				'choices'         => array(
					'original'       => esc_html__( 'Original', 'verta' ),
					'landscape-16-9' => esc_html__( 'Landscape 16:9', 'verta' ),
					'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'verta' ),
					'landscape'      => esc_html__( 'Landscape 4:3', 'verta' ),
					'square'         => esc_html__( 'Square', 'verta' ),
					'portrait'       => esc_html__( 'Portrait', 'verta' ),
					'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'verta' ),
				),
				'active_callback' => array(
					array(
						'field'    => '$#featured_image',
						'operator' => '===',
						'value'    => true,
					),
				),
			),
			array(
				'key'             => 'imageSize',
				'label'           => esc_html__( 'Image Size', 'verta' ),
				'section'         => 'thumbnail',
				'type'            => 'select',
				'default'         => 'large',
				'choices'         => $image_sizes,
				'active_callback' => array(
					array(
						'field'    => '$#featured_image',
						'operator' => '===',
						'value'    => true,
					),
				),
			),
			// Color Settings.
			array(
				'key'     => 'colorBasicHeading',
				'label'   => esc_html__( 'Heading', 'verta' ),
				'section' => 'color',
				'type'    => 'color',
				'output'  => array(
					array(
						'element'  => '$ .cs-tiles-categories__title',
						'property' => '--cs-color-accent',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'     => 'colorBasicHeadingHover',
				'label'   => esc_html__( 'Heading Hover', 'verta' ),
				'section' => 'color',
				'type'    => 'color',
				'output'  => array(
					array(
						'element'  => '$ .cs-tiles-categories__title:hover',
						'property' => '--cs-color-secondary',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'     => 'colorBasicExcerpt',
				'label'   => esc_html__( 'Excerpt', 'verta' ),
				'section' => 'color',
				'type'    => 'color',
				'output'  => array(
					array(
						'element'  => '$ .cs-tiles-categories__excerpt',
						'property' => 'color',
						'suffix'   => '!important',
					),
				),
			),
		),
	);

	$locations['vertical-list']['fields'] = array(
		// Color Settings.
		array(
			'key'     => 'feature_categories_color',
			'label'   => esc_html__( 'Text color', 'verta' ),
			'section' => 'color',
			'type'    => 'color',
			'output'  => array(
				array(
					'element'  => '$ .pk-featured-content .pk-featured-name',
					'property' => 'color',
					'suffix'   => '!important',
				),
			),
		),
	);

	$locations['standard'] = array(
		'name'        => esc_html__( 'Standard', 'verta' ),
		'icon'        => '<svg height="44" viewBox="0 0 52 44" width="52" xmlns="http://www.w3.org/2000/svg"><g fill="none" fill-rule="evenodd" transform="translate(1 1)"><g stroke="#2d2d2d"><rect height="42" rx="3" stroke-width="1.5" width="50"/><rect height="14" rx="1" stroke-width="1.5" width="18" x="16" y="8"/><path d="m21.412325 28h7" stroke-linecap="round" stroke-linejoin="round"/><path d="m17 31h16" stroke-linecap="round" stroke-linejoin="round"/><path d="m19.5 34h11" stroke-linecap="round" stroke-linejoin="round"/></g></g></svg>',
		'location'    => array(),
		'template'    => get_template_directory() . '/template-parts/blocks/categories-standard.php',
		'sections'    => array(
			'general'    => array(
				'title'    => esc_html__( 'Block Settings', 'verta' ),
				'priority' => 5,
				'open'     => true,
			),
			'typography' => array(
				'title'    => esc_html__( 'Typography Settings', 'verta' ),
				'priority' => 10,
			),
			'thumbnail'  => array(
				'title'    => esc_html__( 'Thumbnail Settings', 'verta' ),
				'priority' => 40,
			),
			'color'      => array(
				'title'    => esc_html__( 'Color Settings', 'verta' ),
				'priority' => 50,
			),
		),
		'hide_fields' => array(
			'number',
			'bgOverlay',
			'bgOpacityOverlay',
		),
		'fields'      => array(
			array(
				'key'            => 'columns',
				'label'          => esc_html__( 'Number of Columns', 'verta' ),
				'section'        => 'general',
				'type'           => 'number',
				'min'            => 1,
				'max'            => 6,
				'default'        => 1,
				'default_tablet' => 1,
				'default_mobile' => 1,
				'responsive'     => true,
				'output'         => array(
					array(
						'element'  => '$ .cs-tiles-categories__wrap',
						'property' => '--cs-categories-grid-columns',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'            => 'gap_posts',
				'label'          => esc_html__( 'Gap between Categories', 'verta' ),
				'type'           => 'dimension',
				'section'        => 'general',
				'responsive'     => true,
				'default'        => '40px',
				'default_tablet' => '40px',
				'default_mobile' => '40px',
				'output'         => array(
					array(
						'element'  => '$ .cs-tiles-categories__wrap',
						'property' => '--cs-categories-grid-gap',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'     => 'descriptionLength',
				'label'   => esc_html__( 'Description length', 'verta' ),
				'section' => 'general',
				'type'    => 'number',
				'step'    => 1,
				'min'     => 0,
				'max'     => 1000,
				'default' => 100,
			),
			array(
				'key'             => 'show_counter',
				'label'           => esc_html__( 'Display counter', 'verta' ),
				'section'         => 'general',
				'type'            => 'toggle',
				'default'         => false,
				'active_callback' => array(
					array(
						'field'    => '$#featured_image',
						'operator' => '===',
						'value'    => true,
					),
				),
			),
			// Typography.
			array(
				'key'        => 'typographyHeading',
				'label'      => esc_html__( 'Heading Font Size', 'verta' ),
				'section'    => 'typography',
				'type'       => 'dimension',
				'default'    => '1.625rem',
				'responsive' => true,
				'output'     => array(
					array(
						'element'  => '$ .cs-tiles-categories__name',
						'property' => 'font-size',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'     => 'typographyHeadingTag',
				'label'   => esc_html__( 'Heading Tag', 'verta' ),
				'section' => 'typography',
				'type'    => 'select',
				'default' => 'span',
				'choices' => array(
					'h1'   => esc_html__( 'H1', 'verta' ),
					'h2'   => esc_html__( 'H2', 'verta' ),
					'h3'   => esc_html__( 'H3', 'verta' ),
					'h4'   => esc_html__( 'H4', 'verta' ),
					'h5'   => esc_html__( 'H5', 'verta' ),
					'h6'   => esc_html__( 'H6', 'verta' ),
					'p'    => esc_html__( 'P', 'verta' ),
					'div'  => esc_html__( 'DIV', 'verta' ),
					'span' => esc_html__( 'SPAN', 'verta' ),
				),
			),
			array(
				'key'             => 'typography_counter',
				'label'           => esc_html__( 'Counter Font Size', 'verta' ),
				'section'         => 'typography',
				'type'            => 'dimension',
				'default'         => '2.5rem',
				'responsive'      => true,
				'output'          => array(
					array(
						'element'  => '$',
						'property' => '--cs-font-numbered-post-size',
						'suffix'   => '!important',
					),
				),
				'active_callback' => array(
					array(
						'field'    => '$#show_counter',
						'operator' => '===',
						'value'    => true,
					),
					array(
						'field'    => '$#featured_image',
						'operator' => '===',
						'value'    => true,
					),
				),
			),
			// Thumbnail.
			array(
				'key'     => 'featured_image',
				'label'   => esc_html__( 'Display Featured Image', 'verta' ),
				'section' => 'thumbnail',
				'type'    => 'toggle',
				'default' => true,
			),
			array(
				'key'             => 'orientation',
				'label'           => esc_html__( 'Image Orientation', 'verta' ),
				'section'         => 'thumbnail',
				'type'            => 'select',
				'default'         => 'original',
				'choices'         => array(
					'original'       => esc_html__( 'Original', 'verta' ),
					'landscape-16-9' => esc_html__( 'Landscape 16:9', 'verta' ),
					'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'verta' ),
					'landscape'      => esc_html__( 'Landscape 4:3', 'verta' ),
					'square'         => esc_html__( 'Square', 'verta' ),
					'portrait'       => esc_html__( 'Portrait', 'verta' ),
					'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'verta' ),
				),
				'active_callback' => array(
					array(
						'field'    => '$#featured_image',
						'operator' => '===',
						'value'    => true,
					),
				),
			),
			array(
				'key'             => 'imageSize',
				'label'           => esc_html__( 'Image Size', 'verta' ),
				'section'         => 'thumbnail',
				'type'            => 'select',
				'default'         => 'large',
				'choices'         => $image_sizes,
				'active_callback' => array(
					array(
						'field'    => '$#featured_image',
						'operator' => '===',
						'value'    => true,
					),
				),
			),
			array(
				'key'             => 'image_width',
				'label'           => esc_html__( 'Image Width', 'verta' ),
				'section'         => 'thumbnail',
				'type'            => 'number',
				'step'            => 10,
				'min'             => 40,
				'max'             => 200,
				'default'         => 140,
				'output'          => array(
					array(
						'element'  => '$ .cs-entry__thumbnail',
						'property' => '--cs-categories-image-width',
						'suffix'   => 'px!important',
					),
				),
				'active_callback' => array(
					array(
						'field'    => '$#featured_image',
						'operator' => '===',
						'value'    => true,
					),
				),
			),
			array(
				'key'             => 'imageBorderRadius',
				'label'           => esc_html__( 'Image Border Radius', 'verta' ),
				'section'         => 'thumbnail',
				'type'            => 'dimension',
				'output'          => array(
					array(
						'element'  => '$ .cs-entry__thumbnail',
						'property' => '--cs-thumbnail-border-radius',
					),
				),
				'active_callback' => array(
					array(
						'field'    => '$#featured_image',
						'operator' => '===',
						'value'    => true,
					),
				),
			),
			// Color Settings.
			array(
				'key'     => 'colorBasicHeading',
				'label'   => esc_html__( 'Heading', 'verta' ),
				'section' => 'color',
				'type'    => 'color',
				'output'  => array(
					array(
						'element'  => '$ .cs-tiles-categories__title',
						'property' => '--cs-color-primary',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'     => 'colorBasicHeadingHover',
				'label'   => esc_html__( 'Heading Hover', 'verta' ),
				'section' => 'color',
				'type'    => 'color',
				'output'  => array(
					array(
						'element'  => '$ .cs-tiles-categories__title:hover',
						'property' => '--cs-color-secondary',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'     => 'colorBasicExcerpt',
				'label'   => esc_html__( 'Excerpt', 'verta' ),
				'section' => 'color',
				'type'    => 'color',
				'output'  => array(
					array(
						'element'  => '$ .cs-tiles-categories__excerpt',
						'property' => 'color',
						'suffix'   => '!important',
					),
				),
			),
		),
	);

	$locations['horizontal'] = array(
		'name'        => esc_html__( 'Horizontal', 'verta' ),
		'icon'        => '<svg height="44" viewBox="0 0 52 44" width="52" xmlns="http://www.w3.org/2000/svg"><g fill="none" fill-rule="evenodd" stroke="#2d2d2d"><rect height="42" rx="3" stroke-width="1.5" width="50" x="1" y="1"/><rect height="14" rx="1" stroke-width="1.5" width="14" x="7" y="15"/><g stroke-linecap="round" stroke-linejoin="round"><path d="m24.5 19.5h7"/><path d="m24.5 22.5h21"/><path d="m24.5 25.5h14"/></g></g></svg>',
		'location'    => array(),
		'template'    => get_template_directory() . '/template-parts/blocks/categories-horizontal.php',
		'sections'    => array(
			'general'    => array(
				'title'    => esc_html__( 'Block Settings', 'verta' ),
				'priority' => 5,
				'open'     => true,
			),
			'typography' => array(
				'title'    => esc_html__( 'Typography Settings', 'verta' ),
				'priority' => 10,
			),
			'thumbnail'  => array(
				'title'    => esc_html__( 'Thumbnail Settings', 'verta' ),
				'priority' => 40,
			),
			'color'      => array(
				'title'    => esc_html__( 'Color Settings', 'verta' ),
				'priority' => 50,
			),
		),
		'hide_fields' => array(
			'number',
			'bgOverlay',
			'bgOpacityOverlay',
		),
		'fields'      => array(
			array(
				'key'            => 'columns',
				'label'          => esc_html__( 'Number of Columns', 'verta' ),
				'section'        => 'general',
				'type'           => 'number',
				'min'            => 1,
				'max'            => 6,
				'default'        => 1,
				'default_tablet' => 1,
				'default_mobile' => 1,
				'responsive'     => true,
				'output'         => array(
					array(
						'element'  => '$ .cs-tiles-categories__wrap',
						'property' => '--cs-categories-grid-columns',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'            => 'gap_posts',
				'label'          => esc_html__( 'Gap between Categories', 'verta' ),
				'type'           => 'dimension',
				'section'        => 'general',
				'responsive'     => true,
				'default'        => '40px',
				'default_tablet' => '40px',
				'default_mobile' => '40px',
				'output'         => array(
					array(
						'element'  => '$ .cs-tiles-categories__wrap',
						'property' => '--cs-categories-grid-gap',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'     => 'descriptionLength',
				'label'   => esc_html__( 'Description length', 'verta' ),
				'section' => 'general',
				'type'    => 'number',
				'step'    => 1,
				'min'     => 0,
				'max'     => 1000,
				'default' => 100,
			),
			// Typography.
			array(
				'key'        => 'typographyHeading',
				'label'      => esc_html__( 'Heading Font Size', 'verta' ),
				'section'    => 'typography',
				'type'       => 'dimension',
				'default'    => '1.625rem',
				'responsive' => true,
				'output'     => array(
					array(
						'element'  => '$ .cs-tiles-categories__name',
						'property' => 'font-size',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'     => 'typographyHeadingTag',
				'label'   => esc_html__( 'Heading Tag', 'verta' ),
				'section' => 'typography',
				'type'    => 'select',
				'default' => 'span',
				'choices' => array(
					'h1'   => esc_html__( 'H1', 'verta' ),
					'h2'   => esc_html__( 'H2', 'verta' ),
					'h3'   => esc_html__( 'H3', 'verta' ),
					'h4'   => esc_html__( 'H4', 'verta' ),
					'h5'   => esc_html__( 'H5', 'verta' ),
					'h6'   => esc_html__( 'H6', 'verta' ),
					'p'    => esc_html__( 'P', 'verta' ),
					'div'  => esc_html__( 'DIV', 'verta' ),
					'span' => esc_html__( 'SPAN', 'verta' ),
				),
			),
			// Thumbnail.
			array(
				'key'     => 'featured_image',
				'label'   => esc_html__( 'Display Featured Image', 'verta' ),
				'section' => 'thumbnail',
				'type'    => 'toggle',
				'default' => true,
			),
			array(
				'key'             => 'orientation',
				'label'           => esc_html__( 'Image Orientation', 'verta' ),
				'section'         => 'thumbnail',
				'type'            => 'select',
				'default'         => 'original',
				'choices'         => array(
					'original'       => esc_html__( 'Original', 'verta' ),
					'landscape-16-9' => esc_html__( 'Landscape 16:9', 'verta' ),
					'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'verta' ),
					'landscape'      => esc_html__( 'Landscape 4:3', 'verta' ),
					'square'         => esc_html__( 'Square', 'verta' ),
					'portrait'       => esc_html__( 'Portrait', 'verta' ),
					'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'verta' ),
				),
				'active_callback' => array(
					array(
						'field'    => '$#featured_image',
						'operator' => '===',
						'value'    => true,
					),
				),
			),
			array(
				'key'             => 'imageSize',
				'label'           => esc_html__( 'Image Size', 'verta' ),
				'section'         => 'thumbnail',
				'type'            => 'select',
				'default'         => 'large',
				'choices'         => $image_sizes,
				'active_callback' => array(
					array(
						'field'    => '$#featured_image',
						'operator' => '===',
						'value'    => true,
					),
				),
			),
			array(
				'key'             => 'image_width',
				'label'           => esc_html__( 'Image Width', 'verta' ),
				'section'         => 'thumbnail',
				'type'            => 'number',
				'step'            => 10,
				'min'             => 40,
				'max'             => 200,
				'default'         => 110,
				'output'          => array(
					array(
						'element'  => '$ .cs-entry__thumbnail',
						'property' => '--cs-categories-image-width',
						'suffix'   => 'px!important',
					),
				),
				'active_callback' => array(
					array(
						'field'    => '$#featured_image',
						'operator' => '===',
						'value'    => true,
					),
				),
			),
			array(
				'key'             => 'imageBorderRadius',
				'label'           => esc_html__( 'Image Border Radius', 'verta' ),
				'section'         => 'thumbnail',
				'type'            => 'dimension',
				'output'          => array(
					array(
						'element'  => '$ .cs-entry__thumbnail',
						'property' => '--cs-thumbnail-border-radius',
					),
				),
				'active_callback' => array(
					array(
						'field'    => '$#featured_image',
						'operator' => '===',
						'value'    => true,
					),
				),
			),
			// Color Settings.
			array(
				'key'     => 'colorBasicHeading',
				'label'   => esc_html__( 'Heading', 'verta' ),
				'section' => 'color',
				'type'    => 'color',
				'output'  => array(
					array(
						'element'  => '$ .cs-tiles-categories__title',
						'property' => '--cs-color-accent',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'     => 'colorBasicHeadingHover',
				'label'   => esc_html__( 'Heading Hover', 'verta' ),
				'section' => 'color',
				'type'    => 'color',
				'output'  => array(
					array(
						'element'  => '$ .cs-tiles-categories__title:hover',
						'property' => '--cs-color-secondary',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'     => 'colorBasicExcerpt',
				'label'   => esc_html__( 'Excerpt', 'verta' ),
				'section' => 'color',
				'type'    => 'color',
				'output'  => array(
					array(
						'element'  => '$ .cs-tiles-categories__excerpt',
						'property' => 'color',
						'suffix'   => '!important',
					),
				),
			),
		),
	);

	ksort( $locations );

	return $locations;
}
add_filter( 'powerkit_featured_categories_locations', 'csco_powerkit_featured_categories_locations' );

/**
 * Widget Author Templates
 *
 * @param array $templates Templates.
 */
function csco_powerkit_widget_author_templates( $templates ) {
	$templates['default']['func'] = 'csco_powerkit_widget_author_custom_template';
	$templates['alternate'] = array(
		'name' => esc_html__( 'Alternate', 'verta' ),
		'func' => 'csco_powerkit_widget_author_custom_template',
	);
	return $templates;
}
add_filter( 'powerkit_widget_author_templates', 'csco_powerkit_widget_author_templates' );

/**
 * Widget Author Custom Templates
 *
 * @param array $author   Author.
 * @param array $args     Args.
 * @param array $params   Params.
 * @param array $instance Instance.
 */
function csco_powerkit_widget_author_custom_template( $author, $args, $params, $instance ) {

	$avatar_size = 80;
	$template    = 'default';
	if ( isset( $params['block_attrs']['className'] ) ) {
		$class_name = explode( ' ', $params['block_attrs']['className'] );
		if ( in_array( 'is-style-alternate', $class_name, true ) ) {
			$template    = 'alternate';
			$avatar_size = 300;
		}
	} elseif ( isset( $params['template'] ) ) {
		$template = $params['template'];
	}

	echo wp_kses_post( $args['before_widget'] );

	$avatar_size = apply_filters( 'powerkit_widget_author_avatar_size', $avatar_size );

	$tag = apply_filters( 'powerkit_widget_author_title_tag', 'h5' );

	if ( 'default' === $template ) {
		?>
		<div class="widget-body">
			<div class="pk-widget-author<?php echo esc_attr( $params['bg_image_id'] ? ' pk-widget-author-with-bg' : '' ); ?>">
				<?php if ( $params['bg_image_id'] ) { ?>
					<div class="pk-widget-author-bg">
						<?php echo wp_get_attachment_image( $params['bg_image_id'], apply_filters( 'powerkit_widget_author_image_size', 'large' ) ); ?>
					</div>
				<?php } ?>

				<div class="pk-widget-author-container<?php echo esc_attr( $params['bg_image_id'] ? ' pk-bg-overlay' : '' ); ?>">
					<?php
					// Title.
					if ( $params['title'] ) {
						$params['widget_title'] = $args['before_title'] . apply_filters( 'widget_title', $params['title'], $instance, 0 ) . $args['after_title']; // XSS.

						echo wp_kses_post( apply_filters( 'powerkit_widget_author_title', $params['widget_title'], $params['title'] ) );
					} elseif ( isset( $params['block_attrs']['title'] )) {
						?>
						<<?php echo esc_html( $tag ); ?> class="pk-main-title">
							<?php echo esc_html( $params['block_attrs']['title'] ); ?>
						</<?php echo esc_html( $tag ); ?>>
						<?php
					}
					?>

					<<?php echo esc_html( $tag ); ?> class="pk-author-title">
						<a href="<?php echo esc_url( get_author_posts_url( $author ) ); ?>" rel="author">
							<?php echo esc_html( get_the_author_meta( 'display_name', $author ) ); ?>
						</a>
					</<?php echo esc_html( $tag ); ?>>

					<?php if ( $params['avatar'] ) { ?>
						<div class="pk-author-avatar">
							<a href="<?php echo esc_url( get_author_posts_url( $author ) ); ?>" rel="author">
								<?php echo get_avatar( $author, $avatar_size ); ?>
							</a>
						</div>
					<?php } ?>

					<div class="pk-author-data">
						<?php
						if ( $params['description'] && get_the_author_meta( 'description', $author ) ) {
							?>
							<div class="author-description pk-color-secondary">
								<?php echo wp_kses_post( powerkit_str_truncate( get_the_author_meta( 'description', $author ), 100 ) ); ?>
							</div>
							<?php
						}
						if ( $params['social_accounts'] && powerkit_module_enabled( 'social_links' ) ) {
							powerkit_author_social_links( $author );
						}
						?>

						<?php
						if ( $params['archive_btn'] ) {
							$href = get_author_posts_url( $author );
							$text = apply_filters( 'powerkit_widget_author_button', esc_html__( 'View Posts', 'verta' ) );

							if ( isset( $params['is_block'] ) && isset( $params['block_attrs'] ) && $params['is_block'] ) {
								?>
								<div class="pk-author-footer">
									<?php powerkit_print_gutenberg_blocks_button( $text, $href, '', 'button', $params['block_attrs'] ); ?>
								</div>
								<?php
							} else {
								?>
								<a href="<?php echo esc_url( $href ); ?>" class="pk-author-button button">
									<?php echo wp_kses_post( $text ); ?>
								</a>
								<?php
							}
						}
						?>
					</div>
				</div>
			</div>
		</div>

	<?php } else { ?>

		<div class="cs-widget-author-alternate">
			<div class="widget-body">
				<div class="pk-widget-author">
					<div class="pk-widget-author-container">
						<?php if ( isset( $params['block_attrs']['title'] ) ) { ?>
							<<?php echo esc_html( $tag ); ?> class="pk-main-title">
								<?php echo esc_html( $params['block_attrs']['title'] ); ?>
							</<?php echo esc_html( $tag ); ?>>
						<?php } ?>

						<<?php echo esc_html( $tag ); ?> class="pk-author-title">
							<a href="<?php echo esc_url( get_author_posts_url( $author ) ); ?>" rel="author">
								<?php echo esc_html( get_the_author_meta( 'display_name', $author ) ); ?>
							</a>
						</<?php echo esc_html( $tag ); ?>>
						<?php if ( $params['avatar'] ) { ?>
							<div class="pk-author-avatar">
								<a href="<?php echo esc_url( get_author_posts_url( $author ) ); ?>" rel="author">
									<?php echo get_avatar( $author, $avatar_size ); ?>
								</a>
							</div>
						<?php } ?>
						<div class="pk-author-data">
							<?php
							if ( $params['description'] && get_the_author_meta( 'description', $author ) ) {
								?>
								<div class="author-description pk-color-secondary">
									<?php echo wp_kses_post( powerkit_str_truncate( get_the_author_meta( 'description', $author ), 100 ) ); ?>
								</div>
								<?php
							}
							if ( $params['social_accounts'] && powerkit_module_enabled( 'social_links' ) ) {
								powerkit_author_social_links( $author );
							}
							?>

							<?php
							if ( $params['archive_btn'] ) {
								$href = get_author_posts_url( $author );
								$text = apply_filters( 'powerkit_widget_author_button', esc_html__( 'View Posts', 'verta' ) );

								if ( isset( $params['is_block'] ) && isset( $params['block_attrs'] ) && $params['is_block'] ) {
									?>
									<div class="pk-author-footer">
										<?php powerkit_print_gutenberg_blocks_button( $text, $href, '', 'button', $params['block_attrs'] ); ?>
									</div>
									<?php
								} else {
									?>
									<a href="<?php echo esc_url( $href ); ?>" class="pk-author-button button">
										<?php echo wp_kses_post( $text ); ?>
									</a>
									<?php
								}
							}
							?>
						</div>
					</div>
				</div>
			</div>
		</div>

		<?php
	}

	// After Widget.
	echo wp_kses_post( $args['after_widget'] );
}

/**
 * Change settings Author
 *
 * @param array $blocks All registered blocks.
 */
function csco_change_settings_author( $blocks ) {

	foreach ( $blocks as $key => $block ) {

		if ( 'canvas/author' === $block['name'] ) {

			$blocks[ $key ]['styles'] = array(
				array(
					'name'  => 'alternate',
					'label' => esc_html__( 'Alternate', 'verta' ),
				),
			);

			csco_smart_array_push( $blocks[ $key ]['fields'], array(
				'key'     => 'title',
				'label'   => esc_html__( 'Title', 'verta' ),
				'section' => 'general',
				'type'    => 'text',
				'default' => esc_html__( 'Author', 'verta' ),
			), 1, true );

		}
	}

	return $blocks;
}
add_filter( 'canvas_register_block_type', 'csco_change_settings_author', 999 );

/**
 * Add custom social links scheme
 *
 * @param array $schemes All schemes.
 */
function csco_powerkit_social_links_color_schemes( $schemes ) {
	$schemes['rounded-horizontal']['name'] = esc_html__( 'Rounded Horizontal', 'verta' );
	return $schemes;
}
add_filter( 'powerkit_social_links_color_schemes', 'csco_powerkit_social_links_color_schemes' );

/**
 * Change settings of opt-in-form
 *
 * @param array $blocks All registered blocks.
 */
function csco_change_settings_opt_in_form( $blocks ) {

	foreach ( $blocks as $key => $block ) {

		if ( 'canvas/opt-in-form' === $block['name'] ) {
			csco_smart_array_push( $blocks[ $key ]['fields'], array(
				'key'     => 'colorBasicButtonBG',
				'label'   => esc_html__( 'Button Background', 'verta' ),
				'section' => 'general',
				'type'    => 'color',
				'output'  => array(
					array(
						'element'  => '$',
						'property' => '--cs-color-button',
						'suffix'   => '!important',
					),
				),
			), false, true );
			csco_smart_array_push( $blocks[ $key ]['fields'], array(
				'key'     => 'colorBasicButton',
				'label'   => esc_html__( 'Button Color', 'verta' ),
				'section' => 'general',
				'type'    => 'color',
				'output'  => array(
					array(
						'element'  => '$',
						'property' => '--cs-color-button-contrast',
						'suffix'   => '!important',
					),
				),
			), false, true );
			csco_smart_array_push( $blocks[ $key ]['fields'], array(
				'key'     => 'colorBasicButtonBGHover',
				'label'   => esc_html__( 'Button Background Hover', 'verta' ),
				'section' => 'general',
				'type'    => 'color',
				'output'  => array(
					array(
						'element'  => '$',
						'property' => '--cs-color-button-hover',
						'suffix'   => '!important',
					),
				),
			), false, true );
			csco_smart_array_push( $blocks[ $key ]['fields'], array(
				'key'     => 'colorBasicButtonHover',
				'label'   => esc_html__( 'Button Color Hover', 'verta' ),
				'section' => 'general',
				'type'    => 'color',
				'output'  => array(
					array(
						'element'  => '$',
						'property' => '--cs-color-button-hover-contrast',
						'suffix'   => '!important',
					),
				),
			), false, true );
		}
	}

	return $blocks;
}
add_filter( 'canvas_register_block_type', 'csco_change_settings_opt_in_form', 999 );

/**
 * Simplify widget title
 *
 * @param string $widget_title Widget title.
 * @param string $title        Title.
 */
function csco_powerkit_simplify_widget_title( $widget_title, $title ) {
	$widget_title = sprintf( '<h5 class="pk-main-title">%s</h5>', $title );

	return $widget_title;
}
add_filter( 'powerkit_widget_about_title', 'csco_powerkit_simplify_widget_title', 10, 2 );
add_filter( 'powerkit_widget_author_title', 'csco_powerkit_simplify_widget_title', 10, 2 );

/**
 * Add exclude selectors of TOC
 *
 * @param string $list List selectors.
 */
function csco_powerkit_toc_exclude_selectors( $list ) {
	$list .= '|.cs-entry__title';

	return $list;
}
add_filter( 'pk_toc_exclude', 'csco_powerkit_toc_exclude_selectors' );

/**
 * Exclude Inline Posts posts from related posts block
 *
 * @param array $args Array of WP_Query args.
 */
function csco_related_posts_args( $args ) {
	global $powerkit_inline_posts;
	if ( ! $powerkit_inline_posts ) {
		return $args;
	}
	$post__not_in         = $args['post__not_in'];
	$post__not_in         = array_unique( array_merge( $post__not_in, $powerkit_inline_posts ) );
	$args['post__not_in'] = $post__not_in;
	return $args;
}

/**
 * PinIt exclude selector
 *
 * @param string $selectors List selectors.
 */
function csco_pinit_exclude_selector( $selectors ) {
	$selectors[] = '.pk-widget-author img';
	return $selectors;
}
add_filter( 'powerkit_pinit_exclude_selectors', 'csco_pinit_exclude_selector' );
