<?php
/**
 * Design
 *
 * @package Verta
 */

CSCO_Kirki::add_section(
	'design',
	array(
		'title'    => esc_html__( 'Design', 'verta' ),
		'priority' => 20,
	)
);

/**
 * -------------------------------------------------------------------------
 * Colors
 * -------------------------------------------------------------------------
 */

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'        => 'collapsible',
		'settings'    => 'design_collapsible_dark_mode',
		'section'     => 'design',
		'label'       => esc_html__( 'Dark Mode', 'verta' ),
		'priority'    => 10,
		'input_attrs' => array(
			'collapsed' => true,
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'radio',
		'settings' => 'color_scheme',
		'label'    => esc_html__( 'Site Color Scheme', 'verta' ),
		'section'  => 'design',
		'default'  => 'system',
		'choices'  => array(
			'system' => esc_html__( 'User’s system preference', 'verta' ),
			'light'  => esc_html__( 'Light', 'verta' ),
			'dark'   => esc_html__( 'Dark', 'verta' ),
		),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'color_scheme_toggle',
		'label'    => esc_html__( 'Enable dark/light mode toggle', 'verta' ),
		'section'  => 'design',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'        => 'collapsible',
		'settings'    => 'design_collapsible_common',
		'section'     => 'design',
		'label'       => esc_html__( 'Light Scheme', 'verta' ),
		'priority'    => 10,
		'input_attrs' => array(
			'collapsed' => true,
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_site_background',
		'label'    => esc_html__( 'Site Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#ffffff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-site-scheme="default"]',
				'property' => '--cs-color-site-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'color',
		'settings'        => 'color_topbar_background',
		'label'           => esc_html__( 'Topbar Background', 'verta' ),
		'section'         => 'design',
		'priority'        => 10,
		'default'         => '#ffffff',
		'choices'         => array(
			'alpha' => true,
		),
		'output'          => array(
			array(
				'element'  => ':root, [data-site-scheme="default"]',
				'property' => '--cs-color-topbar-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'three', 'four', 'five', 'six', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_header_background',
		'label'    => esc_html__( 'Header Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#ffffff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-site-scheme="default"]',
				'property' => '--cs-color-header-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_submenu_background',
		'label'    => esc_html__( 'Submenu Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#ffffff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-site-scheme="default"]',
				'property' => '--cs-color-submenu-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_header_search_background',
		'label'    => esc_html__( 'Header Search Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#ffffff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '.cs-topbar .cs-search__nav-form .cs-search__group',
				'property' => '--cs-color-search-input-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_site_search_background',
		'label'    => esc_html__( 'Site Search Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#f8f9fa',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-site-scheme="default"]',
				'property' => '--cs-color-search-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_footer_background',
		'label'    => esc_html__( 'Footer Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#091a3e',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-site-scheme="default"]',
				'property' => '--cs-color-footer-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_overlay',
		'label'    => esc_html__( 'Overlay Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => 'rgba(0,0,0,0.25)',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-overlay-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'custom',
		'settings' => 'color_' . wp_unique_id( 'divider_' ),
		'section'  => 'design',
		'default'  => '<div class="cs-customizer-divider"></div>',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_secondary',
		'label'    => esc_html__( 'Secondary Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#818181',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-secondary',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-palette-color-secondary',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_secondary_contrast',
		'label'    => esc_html__( 'Secondary Contrast Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#000000',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-secondary-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_secondary_background',
		'label'    => esc_html__( 'Secondary Background Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#f8f3ee',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-secondary-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_accent_background',
		'label'    => esc_html__( 'Accent Background Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#f8f8f7',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-accent-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_accent',
		'label'    => esc_html__( 'Accent Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#68b4a5',
		'context'  => array( 'editor', 'front' ),
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-accent',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_accent_contrast',
		'label'    => esc_html__( 'Accent Contrast Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#ffffff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-accent-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'custom',
		'settings' => 'color_' . wp_unique_id( 'divider_' ),
		'section'  => 'design',
		'default'  => '<div class="cs-customizer-divider"></div>',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_menu_active',
		'label'    => esc_html__( 'Menu Active Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#163477',
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-menu-active',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_menu_hover',
		'label'    => esc_html__( 'Menu Hover Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#377b6d',
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-menu-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_submenu_active',
		'label'    => esc_html__( 'Submenu Active Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#163477',
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-submenu-active',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_submenu_hover',
		'label'    => esc_html__( 'Submenu Hover Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#377b6d',
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-submenu-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'custom',
		'settings' => 'color_' . wp_unique_id( 'divider_' ),
		'section'  => 'design',
		'default'  => '<div class="cs-customizer-divider"></div>',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_button',
		'label'    => esc_html__( 'Button Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#163477',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-button',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_button_contrast',
		'label'    => esc_html__( 'Button Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#ffffff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-button-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_button_hover',
		'label'    => esc_html__( 'Button Hover Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#0f8971',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-button-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_button_hover_contrast',
		'label'    => esc_html__( 'Button Hover Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#ffffff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-button-hover-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'custom',
		'settings' => 'color_' . wp_unique_id( 'divider_' ),
		'section'  => 'design',
		'default'  => '<div class="cs-customizer-divider"></div>',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_category',
		'label'    => esc_html__( 'Category Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#326dff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-category',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_category_hover',
		'label'    => esc_html__( 'Category Hover Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#0f8971',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-category-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_styled_category',
		'label'    => esc_html__( 'Styled Category Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#326dff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-styled-category',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_styled_category_contrast',
		'label'    => esc_html__( 'Styled Category Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#ffffff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-styled-category-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_styled_category_hover',
		'label'    => esc_html__( 'Styled Category Hover Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#326dff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root .cs-entry__post-meta .cs-meta-category a, [data-scheme="default"] .cs-entry__post-meta .cs-meta-category a',
				'property' => '--cs-color-styled-category-hover',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => ':root .cs-entry__post-meta .cs-meta-category a:hover, [data-scheme="default"] .cs-entry__post-meta .cs-meta-category a:hover',
				'property' => '--cs-color-styled-category',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_styled_category_hover_contrast',
		'label'    => esc_html__( 'Styled Category Hover Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#000000',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-styled-category-hover-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_category_underline',
		'label'    => esc_html__( 'Category Underline Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#326dff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-category-underline',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'custom',
		'settings' => 'color_' . wp_unique_id( 'divider_' ),
		'section'  => 'design',
		'default'  => '<div class="cs-customizer-divider"></div>',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_meta',
		'label'    => esc_html__( 'Post Meta Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#818181',
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-post-meta',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_meta_link',
		'label'    => esc_html__( 'Post Meta Link Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#000000',
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-post-meta-link',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_meata_link_hover',
		'label'    => esc_html__( 'Post Meta Link Hover Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#818181',
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-post-meta-link-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

/** Dark Scheme */
CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'design_collapsible_dark',
		'section'  => 'design',
		'label'    => esc_html__( 'Dark Scheme', 'verta' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_site_background_dark',
		'label'    => esc_html__( 'Site Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#1c1c1c',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-site-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'color',
		'settings'        => 'color_topbar_background_dark',
		'label'           => esc_html__( 'Topbar Background', 'verta' ),
		'section'         => 'design',
		'priority'        => 10,
		'default'         => '#1c1c1c',
		'choices'         => array(
			'alpha' => true,
		),
		'output'          => array(
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-topbar-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'three', 'four', 'five', 'six', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_header_background_dark',
		'label'    => esc_html__( 'Header Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#1c1c1c',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-header-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_submenu_background_dark',
		'label'    => esc_html__( 'Submenu Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#1c1c1c',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-submenu-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_header_search_background_dark',
		'label'    => esc_html__( 'Header Search Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#000000',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-site-scheme="dark"] .cs-topbar .cs-search__nav-form .cs-search__group',
				'property' => '--cs-color-search-input-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_search_background_dark',
		'label'    => esc_html__( 'Site Search Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#333333',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-search-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_footer_background_dark',
		'label'    => esc_html__( 'Footer Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#333333',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-footer-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'custom',
		'settings' => 'color_' . wp_unique_id( 'divider_' ),
		'section'  => 'design',
		'default'  => '<div class="cs-customizer-divider"></div>',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_secondary_dark',
		'label'    => esc_html__( 'Secondary Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#858585',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-secondary',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-palette-color-secondary',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_secondary_contrast_dark',
		'label'    => esc_html__( 'Secondary Contrast Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#000000',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-secondary-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_secondary_background_dark',
		'label'    => esc_html__( 'Secondary Background Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#333333',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-secondary-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_accent_background_dark',
		'label'    => esc_html__( 'Accent Background Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#333333',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-accent-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'custom',
		'settings' => 'color_' . wp_unique_id( 'divider_' ),
		'section'  => 'design',
		'default'  => '<div class="cs-customizer-divider"></div>',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_menu_active_dark',
		'label'    => esc_html__( 'Menu Active Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#858585',
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-menu-active',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_menu_hover_dark',
		'label'    => esc_html__( 'Menu Hover Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#858585',
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-menu-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_submenu_active_dark',
		'label'    => esc_html__( 'Submenu Active Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#858585',
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-submenu-active',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_submenu_hover_dark',
		'label'    => esc_html__( 'Submenu Hover Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#858585',
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-submenu-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'custom',
		'settings' => 'color_' . wp_unique_id( 'divider_' ),
		'section'  => 'design',
		'default'  => '<div class="cs-customizer-divider"></div>',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_button_dark',
		'label'    => esc_html__( 'Button Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#163477',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-button',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_button_contrast_dark',
		'label'    => esc_html__( 'Button Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#ffffff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-button-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_button_hover_dark',
		'label'    => esc_html__( 'Button Hover Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#0f8971',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-button-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_button_hover_contrast_dark',
		'label'    => esc_html__( 'Button Hover Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#ffffff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-button-hover-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'custom',
		'settings' => 'color_' . wp_unique_id( 'divider_' ),
		'section'  => 'design',
		'default'  => '<div class="cs-customizer-divider"></div>',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_category_dark',
		'label'    => esc_html__( 'Category Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#ffffff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-category',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_category_hover_dark',
		'label'    => esc_html__( 'Category Hover Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#ffffff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-category-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_styled_category_dark',
		'label'    => esc_html__( 'Styled Category Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#172dca',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-styled-category',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_styled_category_contrast_dark',
		'label'    => esc_html__( 'Styled Category Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#ffffff',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-styled-category-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_styled_category_hover_dark',
		'label'    => esc_html__( 'Styled Category Hover Background', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#172dca',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"] .cs-entry__post-meta .cs-meta-category a',
				'property' => '--cs-color-styled-category-hover',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => '[data-scheme="dark"] .cs-entry__post-meta .cs-meta-category a:hover',
				'property' => '--cs-color-styled-category',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_styled_category_hover_contrast_dark',
		'label'    => esc_html__( 'Styled Category Hover Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#000000',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-styled-category-hover-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_category_underline_dark',
		'label'    => esc_html__( 'Category Underline Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#172dca',
		'choices'  => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-category-underline',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'custom',
		'settings' => 'color_' . wp_unique_id( 'divider_' ),
		'section'  => 'design',
		'default'  => '<div class="cs-customizer-divider"></div>',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_meta_dark',
		'label'    => esc_html__( 'Post Meta Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#818181',
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-post-meta',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_meta_link_dark',
		'label'    => esc_html__( 'Post Meta Link Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#ffffff',
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-post-meta-link',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'color',
		'settings' => 'color_meata_link_hover_dark',
		'label'    => esc_html__( 'Post Meta Link Hover Color', 'verta' ),
		'section'  => 'design',
		'priority' => 10,
		'default'  => '#818181',
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-post-meta-link-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

/** Border Radius */
CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'design_collapsible_border_radius',
		'section'  => 'design',
		'label'    => esc_html__( 'Border Radius', 'verta' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'        => 'custom',
		'settings'    => 'design_border_radius_desc',
		'section'     => 'design',
		'description' => esc_html__( 'Here you can change default border radius for Layout Elements, post Thumbnail, Buttons and Styled Categories. For example 10px or 50%. If the input is empty, original value will be used.', 'verta' ),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'              => 'dimension',
		'settings'          => 'design_layout elements_border_radius',
		'label'             => esc_html__( 'Layout Elements', 'verta' ),
		'description'       => esc_html__( 'Used on Form Elements, Blockquotes, Block Groups etc.', 'verta' ),
		'section'           => 'design',
		'default'           => '0px',
		'priority'          => 10,
		'sanitize_callback' => 'esc_html',
		'output'            => array(
			array(
				'element'  => ':root',
				'property' => '--cs-layout-elements-border-radius',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'              => 'dimension',
		'settings'          => 'design_thumbnail_border_radius',
		'label'             => esc_html__( 'Thumbnail Border Radius', 'verta' ),
		'section'           => 'design',
		'default'           => '0px',
		'priority'          => 10,
		'sanitize_callback' => 'esc_html',
		'output'            => array(
			array(
				'element'  => ':root',
				'property' => '--cs-thumbnail-border-radius',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'              => 'dimension',
		'settings'          => 'design_button_border_radius',
		'label'             => esc_html__( 'Button Border Radius', 'verta' ),
		'section'           => 'design',
		'default'           => '0px',
		'priority'          => 10,
		'sanitize_callback' => 'esc_html',
		'output'            => array(
			array(
				'element'  => ':root',
				'property' => '--cs-button-border-radius',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'              => 'dimension',
		'settings'          => 'design_styled_category_border_radius',
		'label'             => esc_html__( 'Styled Category Border Radius', 'verta' ),
		'section'           => 'design',
		'default'           => '0px',
		'priority'          => 10,
		'sanitize_callback' => 'esc_html',
		'output'            => array(
			array(
				'element'  => ':root',
				'property' => '--cs-category-label-border-radius',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

/** Subscription Forms Style */
if ( csco_powerkit_module_enabled( 'opt_in_forms' ) ) {
	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'     => 'collapsible',
			'settings' => 'design_collapsible_form_style',
			'section'  => 'design',
			'label'    => esc_html__( 'Subscription Forms Style', 'verta' ),
			'priority' => 10,
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'     => 'select',
			'settings' => 'form_style_header',
			'label'    => esc_html__( 'Form Style for Header', 'verta' ),
			'section'  => 'design',
			'default'  => 'one',
			'choices'  => array(
				'one'   => esc_html__( 'Style 1', 'verta' ),
				'two'   => esc_html__( 'Style 2', 'verta' ),
				'three' => esc_html__( 'Style 3', 'verta' ),
			),
			'priority' => 10,
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'     => 'select',
			'settings' => 'form_style_content',
			'label'    => esc_html__( 'Form Style for Content', 'verta' ),
			'section'  => 'design',
			'default'  => 'three',
			'choices'  => array(
				'one'   => esc_html__( 'Style 1', 'verta' ),
				'two'   => esc_html__( 'Style 2', 'verta' ),
				'three' => esc_html__( 'Style 3', 'verta' ),
			),
			'priority' => 10,
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'     => 'select',
			'settings' => 'form_style_footer',
			'label'    => esc_html__( 'Form Style for Footer', 'verta' ),
			'section'  => 'design',
			'default'  => 'three',
			'choices'  => array(
				'one'   => esc_html__( 'Style 1', 'verta' ),
				'two'   => esc_html__( 'Style 2', 'verta' ),
				'three' => esc_html__( 'Style 3', 'verta' ),
			),
			'priority' => 10,
		)
	);
}
