<?php
/**
 * Header Settings
 *
 * @package Verta
 */

CSCO_Kirki::add_section(
	'header',
	array(
		'title'    => esc_html__( 'Header Settings', 'verta' ),
		'priority' => 40,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'        => 'collapsible',
		'settings'    => 'header_collapsible_common',
		'section'     => 'header',
		'label'       => esc_html__( 'Common', 'verta' ),
		'priority'    => 10,
		'input_attrs' => array(
			'collapsed' => true,
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'radio',
		'settings' => 'header_layout',
		'label'    => esc_html__( 'Layout', 'verta' ),
		'section'  => 'header',
		'default'  => 'six',
		'priority' => 10,
		'choices'  => array(
			'one'   => esc_html__( 'Header 1', 'verta' ),
			'two'   => esc_html__( 'Header 2', 'verta' ),
			'three' => esc_html__( 'Header 3', 'verta' ),
			'four'  => esc_html__( 'Header 4', 'verta' ),
			'five'  => esc_html__( 'Header 5', 'verta' ),
			'six'   => esc_html__( 'Header 6', 'verta' ),
			'seven' => esc_html__( 'Header 7', 'verta' ),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'dimension',
		'settings'        => 'header_topbar_height',
		'label'           => esc_html__( 'Topbar Height', 'verta' ),
		'section'         => 'header',
		'default'         => '90px',
		'priority'        => 10,
		'output'          => array(
			array(
				'element'  => ':root',
				'property' => '--cs-header-topbar-height',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'three', 'four', 'five', 'six', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'dimension',
		'settings' => 'header_height',
		'label'    => esc_html__( 'Header Height', 'verta' ),
		'section'  => 'header',
		'default'  => '60px',
		'priority' => 10,
		'output'   => array(
			array(
				'element'  => ':root',
				'property' => '--cs-header-height',
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'topbar_border',
		'label'    => esc_html__( 'Display header border', 'verta' ),
		'section'  => 'header',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'        => 'checkbox',
		'settings'    => 'navbar_sticky',
		'label'       => esc_html__( 'Make navigation bar sticky', 'verta' ),
		'description' => esc_html__( 'Enabling this option will make navigation bar visible when scrolling.', 'verta' ),
		'section'     => 'header',
		'default'     => true,
		'priority'    => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'checkbox',
		'settings'        => 'navbar_smart_sticky',
		'label'           => esc_html__( 'Enable the smart sticky feature', 'verta' ),
		'description'     => esc_html__( 'Enabling this option will reveal navigation bar when scrolling up and hide it when scrolling down.', 'verta' ),
		'section'         => 'header',
		'default'         => true,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'navbar_sticky',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'header_offcanvas',
		'label'    => esc_html__( 'Display offcanvas toggle button', 'verta' ),
		'section'  => 'header',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'header_navigation_menu',
		'label'    => esc_html__( 'Display navigation menu', 'verta' ),
		'section'  => 'header',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'              => 'textarea',
		'settings'          => 'header_info',
		'label'             => esc_html__( 'Header Info Text', 'verta' ),
		'section'           => 'header',
		'default'           => '',
		'priority'          => 10,
		'sanitize_callback' => 'wp_kses_post',
		'active_callback'   => array(
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'five', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'header_collapsible_search',
		'section'  => 'header',
		'label'    => esc_html__( 'Search', 'verta' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'checkbox',
		'settings'        => 'header_search_form',
		'label'           => esc_html__( 'Display search form', 'verta' ),
		'section'         => 'header',
		'default'         => true,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'three', 'four', 'five', 'six', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'checkbox',
		'settings'        => 'header_search_form_border',
		'label'           => esc_html__( 'Display search form border', 'verta' ),
		'section'         => 'header',
		'default'         => true,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'header_search_form',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'three', 'four', 'five', 'six', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'text',
		'settings'        => 'header_search_width',
		'label'           => esc_html__( 'Search form width', 'verta' ),
		'section'         => 'header',
		'default'         => '',
		'priority'        => 10,
		'input_attrs'     => array(
			'placeholder' => esc_html__( '270px', 'verta' ),
		),
		'output'          => array(
			array(
				'element'  => '.cs-topbar .cs-search__nav-form',
				'property' => '--cs-search-input-wigth',
				'context'  => array( 'editor', 'front' ),
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_form',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'three', 'four', 'five', 'six', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'checkbox',
		'settings'        => 'header_search_button',
		'label'           => esc_html__( 'Display search button', 'verta' ),
		'section'         => 'header',
		'default'         => true,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'one', 'two', 'three', 'four', 'five', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'checkbox',
		'settings'        => 'header_search_posts',
		'label'           => esc_html__( 'Display search posts', 'verta' ),
		'description'     => esc_html__( 'Display posts in popup search form.', 'verta' ),
		'section'         => 'header',
		'default'         => true,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'header_search_button',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'one', 'two', 'three', 'four', 'five', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'text',
		'settings'        => 'header_search_posts_heading',
		'label'           => esc_html__( 'Heading of Posts', 'verta' ),
		'section'         => 'header',
		'default'         => esc_html__( 'The Latest', 'verta' ),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'header_search_button',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'one', 'two', 'three', 'four', 'five', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'select',
		'settings'        => 'header_search_image_orientation',
		'label'           => esc_html__( 'Image Orientation', 'verta' ),
		'section'         => 'header',
		'default'         => 'square',
		'choices'         => array(
			'original'  => esc_html__( 'Original', 'verta' ),
			'landscape' => esc_html__( 'Landscape', 'verta' ),
			'portrait'  => esc_html__( 'Portrait', 'verta' ),
			'square'    => esc_html__( 'Square', 'verta' ),
		),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'header_search_button',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'one', 'two', 'three', 'four', 'five', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'select',
		'settings'        => 'header_search_image_size',
		'label'           => esc_html__( 'Image Size', 'verta' ),
		'section'         => 'header',
		'default'         => 'csco-smaller',
		'choices'         => csco_get_list_available_image_sizes(),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'header_search_button',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'one', 'two', 'three', 'four', 'five', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'dimension',
		'settings'        => 'header_search_image_border_radius',
		'label'           => esc_html__( 'Image Border Radius', 'verta' ),
		'section'         => 'header',
		'default'         => '30px',
		'priority'        => 10,
		'output'          => array(
			array(
				'element'  => '.cs-search__posts',
				'property' => '--cs-thumbnail-border-radius',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_button',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'one', 'two', 'three', 'four', 'five', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'multicheck',
		'settings'        => 'header_search_posts_meta',
		'label'           => esc_html__( 'Post Meta', 'verta' ),
		'section'         => 'header',
		'default'         => array( 'views', 'shares' ),
		'priority'        => 10,
		'choices'         => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'verta' ),
				'date'         => esc_html__( 'Date', 'verta' ),
				'author'       => esc_html__( 'Author', 'verta' ),
				'views'        => esc_html__( 'Views', 'verta' ),
				'shares'       => esc_html__( 'Shares', 'verta' ),
				'comments'     => esc_html__( 'Comments', 'verta' ),
				'reading_time' => esc_html__( 'Reading Time', 'verta' ),
			)
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_button',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'one', 'two', 'three', 'four', 'five', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'radio',
		'settings'        => 'header_search_posts_orderby',
		'label'           => esc_html__( 'Order posts by', 'verta' ),
		'section'         => 'header',
		'default'         => 'date',
		'priority'        => 10,
		'choices'         => array(
			'date' => esc_html__( 'Date', 'verta' ),
			'rand' => esc_html__( 'Random', 'verta' ),
			'name' => esc_html__( 'Name', 'verta' ),
			'id'   => esc_html__( 'ID', 'verta' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_button',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'one', 'two', 'three', 'four', 'five', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'radio',
		'settings'        => 'header_search_posts_order',
		'label'           => esc_html__( 'Order posts', 'verta' ),
		'section'         => 'header',
		'default'         => 'DESC',
		'priority'        => 10,
		'choices'         => array(
			'ASC'  => esc_html__( 'ASC', 'verta' ),
			'DESC' => esc_html__( 'DESC', 'verta' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_button',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'one', 'two', 'three', 'four', 'five', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'checkbox',
		'settings'        => 'header_search_tags',
		'label'           => esc_html__( 'Display search tags', 'verta' ),
		'description'     => esc_html__( 'Display tags in popup search form.', 'verta' ),
		'section'         => 'header',
		'default'         => true,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'header_search_button',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'one', 'two', 'three', 'four', 'five', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'number',
		'settings'        => 'header_search_tags_number',
		'label'           => esc_html__( 'Maximum Number of Tags', 'verta' ),
		'section'         => 'header',
		'default'         => 10,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'header_search_button',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_tags',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'one', 'two', 'three', 'four', 'five', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'radio',
		'settings'        => 'header_search_tags_orderby',
		'label'           => esc_html__( 'Order tags by', 'verta' ),
		'section'         => 'header',
		'default'         => 'date',
		'priority'        => 10,
		'choices'         => array(
			'date'  => esc_html__( 'Date', 'verta' ),
			'count' => esc_html__( 'Count of Posts', 'verta' ),
			'name'  => esc_html__( 'Name', 'verta' ),
			'id'    => esc_html__( 'ID', 'verta' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_button',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_tags',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'one', 'two', 'three', 'four', 'five', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'radio',
		'settings'        => 'header_search_tags_order',
		'label'           => esc_html__( 'Order tags', 'verta' ),
		'section'         => 'header',
		'default'         => 'DESC',
		'priority'        => 10,
		'choices'         => array(
			'ASC'  => esc_html__( 'ASC', 'verta' ),
			'DESC' => esc_html__( 'DESC', 'verta' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_button',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_tags',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_layout',
				'operator' => 'in',
				'value'    => array( 'one', 'two', 'three', 'four', 'five', 'seven' ),
			),
		),
	)
);

if ( csco_powerkit_module_enabled( 'social_links' ) ) {
	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'     => 'collapsible',
			'settings' => 'header_collapsible_social_links',
			'section'  => 'header',
			'label'    => esc_html__( 'Social Links', 'verta' ),
			'priority' => 10,
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'     => 'checkbox',
			'settings' => 'header_social_links',
			'label'    => esc_html__( 'Display social links', 'verta' ),
			'section'  => 'header',
			'default'  => false,
			'priority' => 10,
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'select',
			'settings'        => 'header_social_links_scheme',
			'label'           => esc_html__( 'Color scheme', 'verta' ),
			'section'         => 'header',
			'default'         => 'light',
			'priority'        => 10,
			'choices'         => array(
				'light' => esc_html__( 'Light', 'verta' ),
				'bold'  => esc_html__( 'Bold', 'verta' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'header_social_links',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'number',
			'settings'        => 'header_social_links_maximum',
			'label'           => esc_html__( 'Maximum Number of Social Links', 'verta' ),
			'section'         => 'header',
			'default'         => 3,
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'header_social_links',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'checkbox',
			'settings'        => 'header_social_links_counts',
			'label'           => esc_html__( 'Display social counts', 'verta' ),
			'section'         => 'header',
			'default'         => true,
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'header_social_links',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);
}

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'header_collapsible_button',
		'section'  => 'header',
		'label'    => esc_html__( 'Custom Button', 'verta' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'              => 'text',
		'settings'          => 'header_button_label',
		'label'             => esc_html__( 'Button Label', 'verta' ),
		'section'           => 'header',
		'default'           => esc_html__( 'Subscribe', 'verta' ),
		'priority'          => 10,
		'sanitize_callback' => 'wp_kses_post',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'              => 'text',
		'settings'          => 'header_button_link',
		'label'             => esc_html__( 'Button Link', 'verta' ),
		'section'           => 'header',
		'default'           => '/',
		'priority'          => 10,
		'sanitize_callback' => 'esc_url_raw',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'header_button_target',
		'label'    => esc_html__( 'Open button link in new tab', 'verta' ),
		'section'  => 'header',
		'default'  => false,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'header_collapsible_image_button',
		'section'  => 'header',
		'label'    => esc_html__( 'Custom Image Button', 'verta' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'              => 'image',
		'settings'          => 'header_image_button',
		'label'             => esc_html__( 'Button Image', 'verta' ),
		'section'           => 'header',
		'priority'          => 10,
		'choices'           => array(
			'save_as' => 'id',
		),
		'sanitize_callback' => 'wp_kses_post',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'              => 'text',
		'settings'          => 'header_image_button_link',
		'label'             => esc_html__( 'Button Link', 'verta' ),
		'section'           => 'header',
		'default'           => '',
		'priority'          => 10,
		'sanitize_callback' => 'esc_url_raw',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'header_image_button_target',
		'label'    => esc_html__( 'Open button link in new tab', 'verta' ),
		'section'  => 'header',
		'default'  => false,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'header_collapsible_multi_column',
		'section'  => 'header',
		'label'    => esc_html__( 'Multi-Column Sub-Menu', 'verta' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'header_multi_column_display',
		'label'    => esc_html__( 'Display multi-column sub-menu', 'verta' ),
		'section'  => 'header',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'header_collapsible_single_column',
		'section'  => 'header',
		'label'    => esc_html__( 'Single-Column Sub-Menu', 'verta' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'header_single_column_display',
		'label'    => esc_html__( 'Display single-column sub-menu', 'verta' ),
		'section'  => 'header',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'image',
		'settings'        => 'header_single_column_image',
		'label'           => esc_html__( 'Background Image', 'verta' ),
		'section'         => 'header',
		'priority'        => 10,
		'choices'         => array(
			'save_as' => 'id',
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_single_column_display',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'header_collapsible_two_column',
		'section'  => 'header',
		'label'    => esc_html__( 'Two-Column Sub-Menu', 'verta' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'header_two_column_display',
		'label'    => esc_html__( 'Display two-column sub-menu', 'verta' ),
		'section'  => 'header',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'text',
		'settings'        => 'header_two_column_title',
		'label'           => esc_html__( 'Dropdown Title', 'verta' ),
		'section'         => 'header',
		'default'         => esc_html__( 'Follow', 'verta' ),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'header_two_column_display',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'header_collapsible_mega_menu',
		'section'  => 'header',
		'label'    => esc_html__( 'Mega Menu', 'verta' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'select',
		'settings' => 'mega_menu_image_orientation',
		'label'    => esc_html__( 'Image Orientation', 'verta' ),
		'section'  => 'header',
		'default'  => 'original',
		'choices'  => array(
			'original'  => esc_html__( 'Original', 'verta' ),
			'landscape' => esc_html__( 'Landscape', 'verta' ),
			'portrait'  => esc_html__( 'Portrait', 'verta' ),
			'square'    => esc_html__( 'Square', 'verta' ),
		),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'select',
		'settings' => 'mega_menu_image_size',
		'label'    => esc_html__( 'Image Size', 'verta' ),
		'section'  => 'header',
		'default'  => 'csco-intermediate',
		'choices'  => csco_get_list_available_image_sizes(),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'multicheck',
		'settings' => 'mega_menu_post_meta',
		'label'    => esc_html__( 'Post Meta', 'verta' ),
		'section'  => 'header',
		'default'  => array( 'category', 'views', 'reading_time' ),
		'priority' => 10,
		'choices'  => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'verta' ),
				'date'         => esc_html__( 'Date', 'verta' ),
				'author'       => esc_html__( 'Author', 'verta' ),
				'views'        => esc_html__( 'Views', 'verta' ),
				'shares'       => esc_html__( 'Shares', 'verta' ),
				'comments'     => esc_html__( 'Comments', 'verta' ),
				'reading_time' => esc_html__( 'Reading Time', 'verta' ),
			)
		),
	)
);
